Groups | Search | Server Info | Keyboard shortcuts | Login | Register [http] [https] [nntp] [nntps]


Groups > linux.debian.user > #178406 > unrolled thread

Printing packages

Started byRodolfo Medina <rodolfo.medina@gmail.com>
First post2017-03-04 19:20 +0100
Last post2017-03-26 19:50 +0200
Articles 20 on this page of 44 — 8 participants

Back to article view | Back to linux.debian.user


Contents

  Printing packages Rodolfo Medina <rodolfo.medina@gmail.com> - 2017-03-04 19:20 +0100
    Re: Printing packages Brian <ad44@cityscape.co.uk> - 2017-03-04 19:30 +0100
      Re: Printing packages Cindy-Sue Causey <butterflybytes@gmail.com> - 2017-03-04 20:10 +0100
        Re: Printing packages Rodolfo Medina <rodolfo.medina@gmail.com> - 2017-03-04 21:00 +0100
          Re: Printing packages Brian <ad44@cityscape.co.uk> - 2017-03-04 21:10 +0100
          Re: Printing packages Lisi Reisz <lisi.reisz@gmail.com> - 2017-03-04 21:20 +0100
            Correction: Re: Printing packages Lisi Reisz <lisi.reisz@gmail.com> - 2017-03-04 21:40 +0100
              Re: Correction: Re: Printing packages Doug <dmcgarrett@optonline.net> - 2017-03-04 23:00 +0100
                Re: Correction: Re: Printing packages Lisi Reisz <lisi.reisz@gmail.com> - 2017-03-04 23:50 +0100
                  Re: Correction: Re: Printing packages Rodolfo Medina <rodolfo.medina@gmail.com> - 2017-03-05 08:00 +0100
                    Re: Correction: Re: Printing packages Liam O'Toole <liam.p.otoole@gmail.com> - 2017-03-05 19:30 +0100
                      Re: Correction: Re: Printing packages Rodolfo Medina <rodolfo.medina@gmail.com> - 2017-03-05 21:00 +0100
            Re: Printing packages Brian <ad44@cityscape.co.uk> - 2017-03-04 21:40 +0100
              Re: Printing packages Rodolfo Medina <rodolfo.medina@gmail.com> - 2017-03-04 22:40 +0100
                Re: Printing packages Lisi Reisz <lisi.reisz@gmail.com> - 2017-03-05 00:10 +0100
                  Re: Printing packages Rodolfo Medina <rodolfo.medina@gmail.com> - 2017-03-05 08:10 +0100
          Re: Printing packages Rodolfo Medina <rodolfo.medina@gmail.com> - 2017-03-27 16:00 +0200
    Re: Printing packages Rodolfo Medina <rodolfo.medina@gmail.com> - 2017-03-05 21:10 +0100
      Re: Printing packages Rodolfo Medina <rodolfo.medina@gmail.com> - 2017-03-05 21:50 +0100
      Re: Printing packages Brian <ad44@cityscape.co.uk> - 2017-03-05 22:00 +0100
        `Filter failed' no print error message (was: Printing packages) Rodolfo Medina <rodolfo.medina@gmail.com> - 2017-03-07 16:50 +0100
          Re: `Filter failed' no print error message (was: Printing packages) Brian <ad44@cityscape.co.uk> - 2017-03-07 18:10 +0100
            Re: `Filter failed' no print error message Rodolfo Medina <rodolfo.medina@gmail.com> - 2017-03-11 22:10 +0100
              Re: `Filter failed' no print error message Brian <ad44@cityscape.co.uk> - 2017-03-12 00:30 +0100
                Re: `Filter failed' no print error message Rodolfo Medina <rodolfo.medina@gmail.com> - 2017-03-13 17:30 +0100
                  Re: `Filter failed' no print error message Rob van der Putten <rob@sput.nl> - 2017-03-13 20:10 +0100
                  Re: `Filter failed' no print error message Brian <ad44@cityscape.co.uk> - 2017-03-13 21:00 +0100
                    Re: `Filter failed' no print error message Rodolfo Medina <rodolfo.medina@gmail.com> - 2017-03-20 19:30 +0100
                      Re: `Filter failed' no print error message Brian <ad44@cityscape.co.uk> - 2017-03-25 13:10 +0100
                        Re: `Filter failed' no print error message Rodolfo Medina <rodolfo.medina@gmail.com> - 2017-03-26 19:00 +0200
                          Re: `Filter failed' no print error message Brian <ad44@cityscape.co.uk> - 2017-03-26 22:00 +0200
                            Re: `Filter failed' no print error message Rodolfo Medina <rodolfo.medina@gmail.com> - 2017-03-26 23:10 +0200
                              Re: `Filter failed' no print error message Brian <ad44@cityscape.co.uk> - 2017-03-27 00:50 +0200
                                Re: `Filter failed' no print error message Rodolfo Medina <rodolfo.medina@gmail.com> - 2017-03-27 08:50 +0200
                                  Re: `Filter failed' no print error message Brian <ad44@cityscape.co.uk> - 2017-03-27 13:10 +0200
                                    Re: `Filter failed' no print error message Rodolfo Medina <rodolfo.medina@gmail.com> - 2017-03-27 15:40 +0200
                                      Re: `Filter failed' no print error message Brian <ad44@cityscape.co.uk> - 2017-03-27 16:40 +0200
                                        Re: `Filter failed' no print error message Rodolfo Medina <rodolfo.medina@gmail.com> - 2017-03-27 17:10 +0200
                                          Re: `Filter failed' no print error message Brian <ad44@cityscape.co.uk> - 2017-03-27 18:20 +0200
                                            Re: `Filter failed' no print error message Rodolfo Medina <rodolfo.medina@gmail.com> - 2017-03-27 19:30 +0200
                                              Re: `Filter failed' no print error message Brian <ad44@cityscape.co.uk> - 2017-03-27 20:20 +0200
                  Re: `Filter failed' no print error message Brian <ad44@cityscape.co.uk> - 2017-03-13 21:10 +0100
          Re: `Filter failed' no print error message Teemu Likonen <tlikonen@iki.fi> - 2017-03-25 14:30 +0100
            Re: `Filter failed' no print error message Rodolfo Medina <rodolfo.medina@gmail.com> - 2017-03-26 19:50 +0200

Page 2 of 3 — ← Prev page 1 [2] 3  Next page →


#178539 — `Filter failed' no print error message (was: Printing packages)

FromRodolfo Medina <rodolfo.medina@gmail.com>
Date2017-03-07 16:50 +0100
Subject`Filter failed' no print error message (was: Printing packages)
Message-ID<tipx7-18u-13@gated-at.bofh.it>
In reply to#178461
Brian <ad44@cityscape.co.uk> writes:

> On Sun 05 Mar 2017 at 20:07:22 +0000, Rodolfo Medina wrote:
>
>> Rodolfo Medina <rodolfo.medina@gmail.com> writes:
>> 
>> 
>> I installed:
>> 
>>   cups cups-bsd cups-client libcupsimage2 printer-driver-gutenprint
>
> For what purpose do you need cups-bsd?
>
> cups-client and libcupsimage2 are Depends: of cups. 'apt-get install cups'
> gives you them. printer-driver-gutenprint is a Recommends:; you should get
> that too.


Thanks, `cups' alone was enough.  Now the printer seems to be configured.  But
it does not print, and, when I get into `jobs', I see they are stopped with
"Filter failed" claim.  What can I do?  Please help.  Thanks.

Rodolfo

[toc] | [prev] | [next] | [standalone]


#178546 — Re: `Filter failed' no print error message (was: Printing packages)

FromBrian <ad44@cityscape.co.uk>
Date2017-03-07 18:10 +0100
SubjectRe: `Filter failed' no print error message (was: Printing packages)
Message-ID<tiqMx-2br-9@gated-at.bofh.it>
In reply to#178539
On Tue 07 Mar 2017 at 15:41:54 +0000, Rodolfo Medina wrote:

> Brian <ad44@cityscape.co.uk> writes:
> 
> > On Sun 05 Mar 2017 at 20:07:22 +0000, Rodolfo Medina wrote:
> >
> >> Rodolfo Medina <rodolfo.medina@gmail.com> writes:
> >> 
> >> 
> >> I installed:
> >> 
> >>   cups cups-bsd cups-client libcupsimage2 printer-driver-gutenprint
> >
> > For what purpose do you need cups-bsd?
> >
> > cups-client and libcupsimage2 are Depends: of cups. 'apt-get install cups'
> > gives you them. printer-driver-gutenprint is a Recommends:; you should get
> > that too.
> 
> 
> Thanks, `cups' alone was enough.  Now the printer seems to be configured.  But
> it does not print, and, when I get into `jobs', I see they are stopped with
> "Filter failed" claim.  What can I do?  Please help.  Thanks.

Read the wiki and find out how to activate debug logging. Produce an
error_log and examine it for the filters which are run and which one
failed. Tell us about all the filters.

Also, post your printer make and model and the output of 'lpstat -t'.

-- 
Brian,

[toc] | [prev] | [next] | [standalone]


#178691 — Re: `Filter failed' no print error message

FromRodolfo Medina <rodolfo.medina@gmail.com>
Date2017-03-11 22:10 +0100
SubjectRe: `Filter failed' no print error message
Message-ID<tjWqZ-8sd-3@gated-at.bofh.it>
In reply to#178546
Brian <ad44@cityscape.co.uk> writes:

> On Tue 07 Mar 2017 at 15:41:54 +0000, Rodolfo Medina wrote:
>
>> 
>> Thanks, `cups' alone was enough.  Now the printer seems to be configured.
>> But it does not print, and, when I get into `jobs', I see they are stopped
>> with "Filter failed" claim.  What can I do?  Please help.  Thanks.
>
> Read the wiki and find out how to activate debug logging. Produce an
> error_log and examine it for the filters which are run and which one
> failed. Tell us about all the filters.
>
> Also, post your printer make and model and the output of 'lpstat -t'.


I noticed that CUPS does not really provide the PPD file I'm adding.  In fact,
there in the managing section, `Modify Printer', where it says `Or Provide a
PPD File', I select the file: ML-191xspl2.ppd, which is in my home directory,
then click on `Modify Printer' and it seems all right; but then, when I get
into it again, the file is no more there, and there is `No file selected'
instead.  Maybe this is related to my `Filter failed' problem...?

Rodolfo

[toc] | [prev] | [next] | [standalone]


#178699 — Re: `Filter failed' no print error message

FromBrian <ad44@cityscape.co.uk>
Date2017-03-12 00:30 +0100
SubjectRe: `Filter failed' no print error message
Message-ID<tjYCt-1sa-3@gated-at.bofh.it>
In reply to#178691
On Sat 11 Mar 2017 at 21:06:23 +0000, Rodolfo Medina wrote:

> Brian <ad44@cityscape.co.uk> writes:
> 
> > On Tue 07 Mar 2017 at 15:41:54 +0000, Rodolfo Medina wrote:
> >
> >> 
> >> Thanks, `cups' alone was enough.  Now the printer seems to be configured.
> >> But it does not print, and, when I get into `jobs', I see they are stopped
> >> with "Filter failed" claim.  What can I do?  Please help.  Thanks.
> >
> > Read the wiki and find out how to activate debug logging. Produce an
> > error_log and examine it for the filters which are run and which one
> > failed. Tell us about all the filters.
> >
> > Also, post your printer make and model and the output of 'lpstat -t'.
> 
> 
> I noticed that CUPS does not really provide the PPD file I'm adding.  In fact,
> there in the managing section, `Modify Printer', where it says `Or Provide a
> PPD File', I select the file: ML-191xspl2.ppd, which is in my home directory,
> then click on `Modify Printer' and it seems all right; but then, when I get
> into it again, the file is no more there, and there is `No file selected'
> instead.  Maybe this is related to my `Filter failed' problem...?

There are seven instructions in the advice given. You haven't provided a
response to any of them. If there is a problem with following what is
required, please ask.

-- 
Brian.

[toc] | [prev] | [next] | [standalone]


#178764 — Re: `Filter failed' no print error message

FromRodolfo Medina <rodolfo.medina@gmail.com>
Date2017-03-13 17:30 +0100
SubjectRe: `Filter failed' no print error message
Message-ID<tkB17-37K-3@gated-at.bofh.it>
In reply to#178699
Brian <ad44@cityscape.co.uk> writes:

> On Sat 11 Mar 2017 at 21:06:23 +0000, Rodolfo Medina wrote:
>
>> Brian <ad44@cityscape.co.uk> writes:
>> 
>> > On Tue 07 Mar 2017 at 15:41:54 +0000, Rodolfo Medina wrote:
>> >
>> >> 
>> >> Thanks, `cups' alone was enough.  Now the printer seems to be configured.
>> >> But it does not print, and, when I get into `jobs', I see they are
>> >> stopped with "Filter failed" claim.  What can I do?  Please help.
>> >> Thanks.
>> >
>> > Read the wiki and find out how to activate debug logging. Produce an
>> > error_log and examine it for the filters which are run and which one
>> > failed. Tell us about all the filters.
>> >
>> > Also, post your printer make and model and the output of 'lpstat -t'.
>> 
>> 
>> I noticed that CUPS does not really provide the PPD file I'm adding.  In
>> fact, there in the managing section, `Modify Printer', where it says `Or
>> Provide a PPD File', I select the file: ML-191xspl2.ppd, which is in my home
>> directory, then click on `Modify Printer' and it seems all right; but then,
>> when I get into it again, the file is no more there, and there is `No file
>> selected' instead.  Maybe this is related to my `Filter failed' problem...?
>
> There are seven instructions in the advice given. You haven't provided a
> response to any of them. If there is a problem with following what is
> required, please ask.

As the wiki suggests, I did:

 # cupsctl --debug-logging

.  Then I did:

$ lpstat -t
scheduler is running
system default destination: Samsung_ML-191x_252x_Series
device for Samsung_ML-191x_252x_Series: usb://Samsung/ML-191x%20252x%20Series?serial=Z2L9BABZ700571F.
Samsung_ML-191x_252x_Series accepting requests since Sun 12 Mar 2017 07:44:58 GMT
printer Samsung_ML-191x_252x_Series is idle.  enabled since Sun 12 Mar 2017 07:44:58 GMT
        Sending data to printer.
Samsung_ML-191x_252x_Series-16 rodolfo         457728   Sat 11 Mar 2017 19:56:36 GMT
Samsung_ML-191x_252x_Series-17 unknown           1024   Sat 11 Mar 2017 20:09:12 GMT
Samsung_ML-191x_252x_Series-18 unknown         457728   Sat 11 Mar 2017 20:20:18 GMT
Samsung_ML-191x_252x_Series-19 rodolfo         457728   Sun 12 Mar 2017 07:44:49 GMT


The file /var/log/cups/error_log is very long.  I noticed in it the following
lines:

D [07/Mar/2017:14:35:23 +0000] [Job 1] Started filter /usr/lib/cups/filter/pdftopdf (PID 4741)
D [07/Mar/2017:14:35:23 +0000] [Job 1] Started filter /usr/lib/cups/filter/pdftops (PID 4742)
D [07/Mar/2017:14:35:23 +0000] [Job 1] Started filter /usr/lib/cups/filter/rastertosamsungspl (PID 4743)
D [07/Mar/2017:14:35:23 +0000] [Job 1] Started backend /usr/lib/cups/backend/usb (PID 4744)
D [07/Mar/2017:14:35:23 +0000] [Job 1] pdftops - copying to temp print file \"/var/spool/cups/tmp/0128658cb23ec\"
D [07/Mar/2017:14:35:23 +0000] [Job 1] execv failed: No such file or directory
D [07/Mar/2017:14:35:23 +0000] [Job 1] PID 4743 (/usr/lib/cups/filter/rastertosamsungspl) stopped with status 102 (No such file or directory)
D [07/Mar/2017:14:35:23 +0000] [Job 1] Hint: Try setting the LogLevel to "debug" to find out more.


Don't know what to do now, please help...

Thanks,

Rodolfo

[toc] | [prev] | [next] | [standalone]


#178774 — Re: `Filter failed' no print error message

FromRob van der Putten <rob@sput.nl>
Date2017-03-13 20:10 +0100
SubjectRe: `Filter failed' no print error message
Message-ID<tkDvX-501-9@gated-at.bofh.it>
In reply to#178764
Hi there


On 13/03/17 17:27, Rodolfo Medina wrote:

> Brian <ad44@cityscape.co.uk> writes:
>
>> On Sat 11 Mar 2017 at 21:06:23 +0000, Rodolfo Medina wrote:
>>
>>> Brian <ad44@cityscape.co.uk> writes:
>>>
>>>> On Tue 07 Mar 2017 at 15:41:54 +0000, Rodolfo Medina wrote:
>>>>
>>>>>
>>>>> Thanks, `cups' alone was enough.  Now the printer seems to be configured.
>>>>> But it does not print, and, when I get into `jobs', I see they are
>>>>> stopped with "Filter failed" claim.  What can I do?  Please help.
>>>>> Thanks.
>>>>
>>>> Read the wiki and find out how to activate debug logging. Produce an
>>>> error_log and examine it for the filters which are run and which one
>>>> failed. Tell us about all the filters.
>>>>
>>>> Also, post your printer make and model and the output of 'lpstat -t'.
>>>
>>>
>>> I noticed that CUPS does not really provide the PPD file I'm adding.  In
>>> fact, there in the managing section, `Modify Printer', where it says `Or
>>> Provide a PPD File', I select the file: ML-191xspl2.ppd, which is in my home
>>> directory, then click on `Modify Printer' and it seems all right; but then,
>>> when I get into it again, the file is no more there, and there is `No file
>>> selected' instead.  Maybe this is related to my `Filter failed' problem...?
>>
>> There are seven instructions in the advice given. You haven't provided a
>> response to any of them. If there is a problem with following what is
>> required, please ask.
>
> As the wiki suggests, I did:
>
>  # cupsctl --debug-logging
>
> .  Then I did:
>
> $ lpstat -t
> scheduler is running
> system default destination: Samsung_ML-191x_252x_Series
> device for Samsung_ML-191x_252x_Series: usb://Samsung/ML-191x%20252x%20Series?serial=Z2L9BABZ700571F.
> Samsung_ML-191x_252x_Series accepting requests since Sun 12 Mar 2017 07:44:58 GMT
> printer Samsung_ML-191x_252x_Series is idle.  enabled since Sun 12 Mar 2017 07:44:58 GMT
>         Sending data to printer.
> Samsung_ML-191x_252x_Series-16 rodolfo         457728   Sat 11 Mar 2017 19:56:36 GMT
> Samsung_ML-191x_252x_Series-17 unknown           1024   Sat 11 Mar 2017 20:09:12 GMT
> Samsung_ML-191x_252x_Series-18 unknown         457728   Sat 11 Mar 2017 20:20:18 GMT
> Samsung_ML-191x_252x_Series-19 rodolfo         457728   Sun 12 Mar 2017 07:44:49 GMT
>
>
> The file /var/log/cups/error_log is very long.  I noticed in it the following
> lines:
>
> D [07/Mar/2017:14:35:23 +0000] [Job 1] Started filter /usr/lib/cups/filter/pdftopdf (PID 4741)
> D [07/Mar/2017:14:35:23 +0000] [Job 1] Started filter /usr/lib/cups/filter/pdftops (PID 4742)
> D [07/Mar/2017:14:35:23 +0000] [Job 1] Started filter /usr/lib/cups/filter/rastertosamsungspl (PID 4743)
> D [07/Mar/2017:14:35:23 +0000] [Job 1] Started backend /usr/lib/cups/backend/usb (PID 4744)
> D [07/Mar/2017:14:35:23 +0000] [Job 1] pdftops - copying to temp print file \"/var/spool/cups/tmp/0128658cb23ec\"
> D [07/Mar/2017:14:35:23 +0000] [Job 1] execv failed: No such file or directory

Someone is calling a program which isn't there. Or the path is wrong.
Does pdftops exist?

> D [07/Mar/2017:14:35:23 +0000] [Job 1] PID 4743 (/usr/lib/cups/filter/rastertosamsungspl) stopped with status 102 (No such file or directory)
> D [07/Mar/2017:14:35:23 +0000] [Job 1] Hint: Try setting the LogLevel to "debug" to find out more.
>
>
> Don't know what to do now, please help...

While installing Jessie I noticed that I had to manually edit some file 
to get things to work. I think it was printers.conf, but I'm not sure.


Regards,
Rob

[toc] | [prev] | [next] | [standalone]


#178782 — Re: `Filter failed' no print error message

FromBrian <ad44@cityscape.co.uk>
Date2017-03-13 21:00 +0100
SubjectRe: `Filter failed' no print error message
Message-ID<tkEim-5lT-13@gated-at.bofh.it>
In reply to#178764
On Mon 13 Mar 2017 at 16:27:30 +0000, Rodolfo Medina wrote:                                                             
                                                                                                                        
> Brian <ad44@cityscape.co.uk> writes:                                                                                  
>                                                                                                                       
> > There are seven instructions in the advice given. You haven't provided a                                            
> > response to any of them. If there is a problem with following what is                                               
> > required, please ask.                                                                                               
>                                                                                                                       
> As the wiki suggests, I did:                                                                                          
>                                                                                                                       
>  # cupsctl --debug-logging                                                                                            
                                                                                                                        
Good.                                                                                                                   
                                                                                                                        
> .  Then I did:                                                                                                        
>                                                                                                                       
> $ lpstat -t                                                                                                           
> scheduler is running                                                                                                  
> system default destination: Samsung_ML-191x_252x_Series                                                               
                                                                                                                        
You have a Samsung ML-191x series B&W printer. It is not supported in                                                   
Debian. From where did you get the necessary drivers?                                                                   
                                                                                                                        
> device for Samsung_ML-191x_252x_Series: usb://Samsung/ML-191x%20252x%20Series?serial=Z2L9BABZ700571F.                 
                                                                                                                        
Encouraging. CUPS has detected the printer is on a USB connection. There                                                
should be no problem printing after your basic problem is sorted out.                                                   
                                                                                                                        
> Samsung_ML-191x_252x_Series accepting requests since Sun 12 Mar 2017 07:44:58 GMT                                     
> printer Samsung_ML-191x_252x_Series is idle.  enabled since Sun 12 Mar 2017 07:44:58 GMT                              
>         Sending data to printer.                                                                                      
                                                                                                                        
Also OK.

> Samsung_ML-191x_252x_Series-16 rodolfo         457728   Sat 11 Mar 2017 19:56:36 GMT                                  
> Samsung_ML-191x_252x_Series-17 unknown           1024   Sat 11 Mar 2017 20:09:12 GMT                                  
> Samsung_ML-191x_252x_Series-18 unknown         457728   Sat 11 Mar 2017 20:20:18 GMT                                  
> Samsung_ML-191x_252x_Series-19 rodolfo         457728   Sun 12 Mar 2017 07:44:49 GMT                                  
                                                                                                                        
These are pending jobs. I can not imagine you want them. Remove with                                                    
'cancel -a -x'. (This is in the wiki, too).                                                                             
                                                                                                                        
> The file /var/log/cups/error_log is very long.  I noticed in it the following                                         
> lines:                                                                                                                
>                                                                                                                       
> D [07/Mar/2017:14:35:23 +0000] [Job 1] Started filter /usr/lib/cups/filter/pdftopdf (PID 4741)                        
                                                                                                                        
This is the first thing that happens to any submitted file. You sent a                                                  
PDF file to the printer. No problem here.                                                                               
                                                                                                                        
> D [07/Mar/2017:14:35:23 +0000] [Job 1] Started filter /usr/lib/cups/filter/pdftops (PID 4742)                         
                                                                                                                        
Eh? The printer does not recognise PostScript. It would print garbage if                                                
it got it. I wonder why the filtering system thinks converting a PDF to                                                 
a PS file is needed. Is there any sign of "gstoraster" in your error_log?                                               
                                                                                                                        
> D [07/Mar/2017:14:35:23 +0000] [Job 1] Started filter /usr/lib/cups/filter/rastertosamsungspl (PID 4743)              
> D [07/Mar/2017:14:35:23 +0000] [Job 1] Started backend /usr/lib/cups/backend/usb (PID 4744)                           
> D [07/Mar/2017:14:35:23 +0000] [Job 1] pdftops - copying to temp print file \"/var/spool/cups/tmp/0128658cb23ec\"     
> D [07/Mar/2017:14:35:23 +0000] [Job 1] execv failed: No such file or directory                                        
> D [07/Mar/2017:14:35:23 +0000] [Job 1] PID 4743 (/usr/lib/cups/filter/rastertosamsungspl) stopped with status 102 (No 
+such file or directory)                                                                                                
> D [07/Mar/2017:14:35:23 +0000] [Job 1] Hint: Try setting the LogLevel to "debug" to find out more.                    
                                                                                                                        
Post the output of 'ls -l /usr/lib/cups/filter'.                                                                        
                                                                                                                        
--                                                                                                                      
Brian.

[toc] | [prev] | [next] | [standalone]


#179048 — Re: `Filter failed' no print error message

FromRodolfo Medina <rodolfo.medina@gmail.com>
Date2017-03-20 19:30 +0100
SubjectRe: `Filter failed' no print error message
Message-ID<tnae8-cZ-85@gated-at.bofh.it>
In reply to#178782
Brian <ad44@cityscape.co.uk> writes:

> Post the output of 'ls -l /usr/lib/cups/filter'.

Here it is:

$ ls -l /usr/lib/cups/filter
total 1332
-rwxr-xr-x 1 root root  43168 Jan 19 13:44 bannertopdf
-rwxr-xr-x 1 root root   1907 Jan 19 13:44 brftoembosser
-rwxr-xr-x 1 root root  10480 Feb 16  2016 commandtocanon
-rwxr-xr-x 1 root root  10496 Feb 16  2016 commandtoepson
-rwxr-xr-x 1 root root  10232 Jan 19 13:44 commandtoescpx
-rwxr-xr-x 1 root root  10232 Jan 19 13:44 commandtopclx
-rwxr-xr-x 1 root root  14328 Jan 31 07:00 commandtops
-rwxr-xr-x 1 root root 109680 Jan 19 13:44 foomatic-rip
-rwxr-xr-x 1 root root    555 Jan 19 13:44 gstopdf
-rwxr-xr-x 1 root root    558 Jan 19 13:44 gstopxl
-rwxr-xr-x 1 root root  22520 Jan 19 13:44 gstoraster
-rwxr-xr-x 1 root root  10232 Jan 31 07:00 gziptoany
-rwxr-xr-x 1 root root   2900 Jan 19 13:44 imagetobrf
-rwxr-xr-x 1 root root  38952 Jan 19 13:44 imagetopdf
-rwxr-xr-x 1 root root    988 Jan 19 13:44 imagetops
-rwxr-xr-x 1 root root  52592 Jan 19 13:44 imagetoraster
lrwxrwxrwx 1 root root     10 Jan 19 13:44 imagetoubrl -> imagetobrf
-rwxr-xr-x 1 root root   6580 Jan 19 13:44 imageubrltoindexv3
-rwxr-xr-x 1 root root   6648 Jan 19 13:44 imageubrltoindexv4
-rwxr-xr-x 1 root root  14328 Jan 19 13:44 mupdftoraster
-rwxr-xr-x 1 root root  22624 Jan 19 13:44 pdftoijs
-rwxr-xr-x 1 root root 145808 Jan 19 13:44 pdftoopvp
-rwxr-xr-x 1 root root 157864 Jan 19 13:44 pdftopdf
-rwxr-xr-x 1 root root  39280 Jan 19 13:44 pdftops
-rwxr-xr-x 1 root root  34984 Jan 19 13:44 pdftoraster
-rwxr-xr-x 1 root root  51224 Jan 31 07:00 pstops
lrwxrwxrwx 1 root root     13 Jan 31 07:00 rastertodymo -> rastertolabel
-rwxr-xr-x 1 root root  18424 Jan 31 07:00 rastertoepson
-rwxr-xr-x 1 root root  30712 Jan 19 13:44 rastertoescpx
-rwxr-xr-x 1 root root  44152 Feb 16  2016 rastertogutenprint.5.2
-rwxr-xr-x 1 root root  18424 Jan 31 07:00 rastertohp
-rwxr-xr-x 1 root root  22520 Jan 31 07:00 rastertolabel
-rwxr-xr-x 1 root root  30712 Jan 19 13:44 rastertopclx
-rwxr-xr-x 1 root root  67680 Jan 19 13:44 rastertopdf
-rwxr-xr-x 1 root root  14328 Jan 19 13:44 rastertops
-rwxr-xr-x 1 root root  14328 Jan 31 07:00 rastertopwg
-rwxr-xr-x 1 root root  44284 Mar  7 14:55 rastertosamsungspl
-rwxr-xr-x 1 root root  26728 Jan 19 13:44 sys5ippprinter
-rwxr-xr-x 1 root root   3111 Jan 19 13:44 textbrftoindexv3
lrwxrwxrwx 1 root root     16 Jan 19 13:44 textbrftoindexv4 -> textbrftoindexv3
-rwxr-xr-x 1 root root   5298 Jan 19 13:44 texttobrf
-rwxr-xr-x 1 root root  58672 Jan 19 13:44 texttopdf
-rwxr-xr-x 1 root root    982 Jan 19 13:44 texttops
-rwxr-xr-x 1 root root  22520 Jan 19 13:44 texttotext
-rwxr-xr-x 1 root root  39008 Jan 19 13:44 urftopdf

Thanks,

Rodolfo

[toc] | [prev] | [next] | [standalone]


#179306 — Re: `Filter failed' no print error message

FromBrian <ad44@cityscape.co.uk>
Date2017-03-25 13:10 +0100
SubjectRe: `Filter failed' no print error message
Message-ID<toSG5-z2-9@gated-at.bofh.it>
In reply to#179048
On Mon 20 Mar 2017 at 18:29:01 +0000, Rodolfo Medina wrote:

> Brian <ad44@cityscape.co.uk> writes:
> 
> > Post the output of 'ls -l /usr/lib/cups/filter'.
> 
> Here it is:
> 
> $ ls -l /usr/lib/cups/filter
> total 1332
> -rwxr-xr-x 1 root root  43168 Jan 19 13:44 bannertopdf
> -rwxr-xr-x 1 root root   1907 Jan 19 13:44 brftoembosser
> -rwxr-xr-x 1 root root  10480 Feb 16  2016 commandtocanon
> -rwxr-xr-x 1 root root  10496 Feb 16  2016 commandtoepson
> -rwxr-xr-x 1 root root  10232 Jan 19 13:44 commandtoescpx
> -rwxr-xr-x 1 root root  10232 Jan 19 13:44 commandtopclx
> -rwxr-xr-x 1 root root  14328 Jan 31 07:00 commandtops
> -rwxr-xr-x 1 root root 109680 Jan 19 13:44 foomatic-rip
> -rwxr-xr-x 1 root root    555 Jan 19 13:44 gstopdf
> -rwxr-xr-x 1 root root    558 Jan 19 13:44 gstopxl
> -rwxr-xr-x 1 root root  22520 Jan 19 13:44 gstoraster
> -rwxr-xr-x 1 root root  10232 Jan 31 07:00 gziptoany
> -rwxr-xr-x 1 root root   2900 Jan 19 13:44 imagetobrf
> -rwxr-xr-x 1 root root  38952 Jan 19 13:44 imagetopdf
> -rwxr-xr-x 1 root root    988 Jan 19 13:44 imagetops
> -rwxr-xr-x 1 root root  52592 Jan 19 13:44 imagetoraster
> lrwxrwxrwx 1 root root     10 Jan 19 13:44 imagetoubrl -> imagetobrf
> -rwxr-xr-x 1 root root   6580 Jan 19 13:44 imageubrltoindexv3
> -rwxr-xr-x 1 root root   6648 Jan 19 13:44 imageubrltoindexv4
> -rwxr-xr-x 1 root root  14328 Jan 19 13:44 mupdftoraster
> -rwxr-xr-x 1 root root  22624 Jan 19 13:44 pdftoijs
> -rwxr-xr-x 1 root root 145808 Jan 19 13:44 pdftoopvp
> -rwxr-xr-x 1 root root 157864 Jan 19 13:44 pdftopdf
> -rwxr-xr-x 1 root root  39280 Jan 19 13:44 pdftops
> -rwxr-xr-x 1 root root  34984 Jan 19 13:44 pdftoraster
> -rwxr-xr-x 1 root root  51224 Jan 31 07:00 pstops
> lrwxrwxrwx 1 root root     13 Jan 31 07:00 rastertodymo -> rastertolabel
> -rwxr-xr-x 1 root root  18424 Jan 31 07:00 rastertoepson
> -rwxr-xr-x 1 root root  30712 Jan 19 13:44 rastertoescpx
> -rwxr-xr-x 1 root root  44152 Feb 16  2016 rastertogutenprint.5.2
> -rwxr-xr-x 1 root root  18424 Jan 31 07:00 rastertohp
> -rwxr-xr-x 1 root root  22520 Jan 31 07:00 rastertolabel
> -rwxr-xr-x 1 root root  30712 Jan 19 13:44 rastertopclx
> -rwxr-xr-x 1 root root  67680 Jan 19 13:44 rastertopdf
> -rwxr-xr-x 1 root root  14328 Jan 19 13:44 rastertops
> -rwxr-xr-x 1 root root  14328 Jan 31 07:00 rastertopwg
> -rwxr-xr-x 1 root root  44284 Mar  7 14:55 rastertosamsungspl
> -rwxr-xr-x 1 root root  26728 Jan 19 13:44 sys5ippprinter
> -rwxr-xr-x 1 root root   3111 Jan 19 13:44 textbrftoindexv3
> lrwxrwxrwx 1 root root     16 Jan 19 13:44 textbrftoindexv4 -> textbrftoindexv3
> -rwxr-xr-x 1 root root   5298 Jan 19 13:44 texttobrf
> -rwxr-xr-x 1 root root  58672 Jan 19 13:44 texttopdf
> -rwxr-xr-x 1 root root    982 Jan 19 13:44 texttops
> -rwxr-xr-x 1 root root  22520 Jan 19 13:44 texttotext
> -rwxr-xr-x 1 root root  39008 Jan 19 13:44 urftopdf

There are two other questions in the mail you are responding to. You 
have not dealt with them. I'll repeat them for reference:

 > From where did you get the necessary drivers?
 > Is there any sign of "gstoraster" in your error_log?

You have rastertosamsungspl as a filter. It needs to be given raster
data. It looks like it is being given PostScript - so the filter stops.

Also provide the outputs of

 cat /etc/cups/ppd/ppd_for_the printer | grep NickName

and 

 cat /etc/cups/ppd/ppd_for_the printer | grep cupsFilter

You will probably have to be root to get these.

-- 
Brian

[toc] | [prev] | [next] | [standalone]


#179377 — Re: `Filter failed' no print error message

FromRodolfo Medina <rodolfo.medina@gmail.com>
Date2017-03-26 19:00 +0200
SubjectRe: `Filter failed' no print error message
Message-ID<tpjGh-2B4-9@gated-at.bofh.it>
In reply to#179306
Brian <ad44@cityscape.co.uk> writes:

> There are two other questions in the mail you are responding to. You 
> have not dealt with them. I'll repeat them for reference:
>
>  > From where did you get the necessary drivers?
>  > Is there any sign of "gstoraster" in your error_log?

Sorry...  No, no gstoraster in error_log.  From UnifiedLinuxDriver_1.02.tar.gz
I extracted ML-191xspl2.ppd and copied it in a subdirectory of my home
directory, and the file rastertosamsungspl that I copied into
/usr/lib/cups/filter.


> You have rastertosamsungspl as a filter. It needs to be given raster
> data. It looks like it is being given PostScript - so the filter stops.
>
> Also provide the outputs of
>
>  cat /etc/cups/ppd/ppd_for_the printer | grep NickName

Here it is:

# cat Samsung_ML-191x_252x_Series.ppd | grep NickName
*ShortNickName: "ML-191x 252x"
*NickName:      "Samsung ML-191x 252x Series"


> and 
>
>  cat /etc/cups/ppd/ppd_for_the printer | grep cupsFilter
>
> You will probably have to be root to get these.


and:

# cat Samsung_ML-191x_252x_Series.ppd | grep cupsFilter
*cupsFilter:  "application/vnd.cups-postscript 0 rastertosamsungspl"

What now?  Thanks...

Rodolfo

[toc] | [prev] | [next] | [standalone]


#179401 — Re: `Filter failed' no print error message

FromBrian <ad44@cityscape.co.uk>
Date2017-03-26 22:00 +0200
SubjectRe: `Filter failed' no print error message
Message-ID<tpmuu-4EH-21@gated-at.bofh.it>
In reply to#179377
On Sun 26 Mar 2017 at 17:58:28 +0100, Rodolfo Medina wrote:

> Brian <ad44@cityscape.co.uk> writes:
> 
> > There are two other questions in the mail you are responding to. You 
> > have not dealt with them. I'll repeat them for reference:
> >
> >  > From where did you get the necessary drivers?
> >  > Is there any sign of "gstoraster" in your error_log?
> 
> Sorry...  No, no gstoraster in error_log.  From UnifiedLinuxDriver_1.02.tar.gz
> I extracted ML-191xspl2.ppd and copied it in a subdirectory of my home
> directory, and the file rastertosamsungspl that I copied into
> /usr/lib/cups/filter.

No gstoraster. You aren't going anywhere. You will not be able to print.

Read that again. Say it to yourself a hundred times. Got it?

"UnifiedLinuxDriver" indicates a package downloaded from

 http://www.bchemnet.com/suldr/

But there is no version 1.02 offered by this site, See here

 http://www.bchemnet.com/suldr/suld.html

Copying the PPD and filter is ok. But what file did you copy them from?
UnifiedLinuxDriver_1.02.tar.gz is not offered by the bchemnet.com site.

Have you got that, too. The file you say you downloaded does not exist
at bchemnet.com as far as I can see.

> > You have rastertosamsungspl as a filter. It needs to be given raster
> > data. It looks like it is being given PostScript - so the filter stops.
> >
> > Also provide the outputs of
> >
> >  cat /etc/cups/ppd/ppd_for_the printer | grep NickName
> 
> Here it is:
> 
> # cat Samsung_ML-191x_252x_Series.ppd | grep NickName
> *ShortNickName: "ML-191x 252x"
> *NickName:      "Samsung ML-191x 252x Series"

Now - that looks ok

> > and 
> >
> >  cat /etc/cups/ppd/ppd_for_the printer | grep cupsFilter
> >
> > You will probably have to be root to get these.
> 
> and:
> 
> # cat Samsung_ML-191x_252x_Series.ppd | grep cupsFilter
> *cupsFilter:  "application/vnd.cups-postscript 0 rastertosamsungspl"
> 
> What now?  Thanks...

What now?

Whatever package you are using is expecting rastertosamsungspl to process
PostScript. As its name implies, it will only process raster data. CUPS
will not like this line.

Please post

 cat Samsung_ML-191x_252x_Series.ppd | grep cupsFilter

for the machine which prints for you. Check the PPD file name in
/etc/cups.ppd first.

-- 
Brian.

[toc] | [prev] | [next] | [standalone]


#179407 — Re: `Filter failed' no print error message

FromRodolfo Medina <rodolfo.medina@gmail.com>
Date2017-03-26 23:10 +0200
SubjectRe: `Filter failed' no print error message
Message-ID<tpnAd-5OK-1@gated-at.bofh.it>
In reply to#179401
Brian <ad44@cityscape.co.uk> writes:

> On Sun 26 Mar 2017 at 17:58:28 +0100, Rodolfo Medina wrote:
>
>> Brian <ad44@cityscape.co.uk> writes:
>> 
>> >  > From where did you get the necessary drivers?
>> >  > Is there any sign of "gstoraster" in your error_log?
>> 
>> No, no gstoraster in error_log.  From UnifiedLinuxDriver_1.02.tar.gz I
>> extracted ML-191xspl2.ppd and copied it in a subdirectory of my home
>> directory, and the file rastertosamsungspl that I copied into
>> /usr/lib/cups/filter.
>
> No gstoraster. You aren't going anywhere. You will not be able to print.
>
> [...]
>
> "UnifiedLinuxDriver" indicates a package downloaded from
>
>  http://www.bchemnet.com/suldr/
>
> But there is no version 1.02 offered by this site, See here
>
>  http://www.bchemnet.com/suldr/suld.html
>
> Copying the PPD and filter is ok. But what file did you copy them from?
> UnifiedLinuxDriver_1.02.tar.gz is not offered by the bchemnet.com site.
>
> Have you got that, too. The file you say you downloaded does not exist
> at bchemnet.com as far as I can see.


I downloaded - years ago, when I bought the printer - from:

 http://www.samsung.com

.  With those two files, the printer had always worked fine with Debian.  Now I
installed Debian on a new machine, and the printer won't print.  Strange
because the old machine, where the printer still does work, *also* has Debian
Sid, the same operating system I have on my new Lenovo AMD A6 Desktop.


>> > You have rastertosamsungspl as a filter. It needs to be given raster
>> > data. It looks like it is being given PostScript - so the filter stops.
>> >
>> > Also provide the outputs of
>> >
>> >  cat /etc/cups/ppd/ppd_for_the printer | grep NickName
>> 
>> Here it is:
>> 
>> # cat Samsung_ML-191x_252x_Series.ppd | grep NickName
>> *ShortNickName: "ML-191x 252x"
>> *NickName:      "Samsung ML-191x 252x Series"
>
> Now - that looks ok
>
>> > and 
>> >
>> >  cat /etc/cups/ppd/ppd_for_the printer | grep cupsFilter
>> >
>> > You will probably have to be root to get these.
>> 
>> and:
>> 
>> # cat Samsung_ML-191x_252x_Series.ppd | grep cupsFilter
>> *cupsFilter:  "application/vnd.cups-postscript 0 rastertosamsungspl"
>> 
>> What now?  Thanks...
>
> What now?
>
> Whatever package you are using is expecting rastertosamsungspl to process
> PostScript. As its name implies, it will only process raster data. CUPS
> will not like this line.
>
> Please post
>
>  cat Samsung_ML-191x_252x_Series.ppd | grep cupsFilter
>
> for the machine which prints for you. Check the PPD file name in
> /etc/cups.ppd first.


Here it is:

*cupsFilter:  "application/vnd.cups-postscript 0 rastertosamsungspl"

, but exactly the same output also comes from Lenovo machine, where the printer
won't work...  So I think there must be some other different special reason
because one is ok and the other is not although the system is the same on both.

Thanks,

Rodolfo

[toc] | [prev] | [next] | [standalone]


#179413 — Re: `Filter failed' no print error message

FromBrian <ad44@cityscape.co.uk>
Date2017-03-27 00:50 +0200
SubjectRe: `Filter failed' no print error message
Message-ID<tpp90-6Ki-11@gated-at.bofh.it>
In reply to#179407
On Sun 26 Mar 2017 at 22:02:44 +0100, Rodolfo Medina wrote:

> Brian <ad44@cityscape.co.uk> writes:
> 
> > On Sun 26 Mar 2017 at 17:58:28 +0100, Rodolfo Medina wrote:
> >
> >> Brian <ad44@cityscape.co.uk> writes:
> >> 
> >> >  > From where did you get the necessary drivers?
> >> >  > Is there any sign of "gstoraster" in your error_log?
> >> 
> >> No, no gstoraster in error_log.  From UnifiedLinuxDriver_1.02.tar.gz I
> >> extracted ML-191xspl2.ppd and copied it in a subdirectory of my home
> >> directory, and the file rastertosamsungspl that I copied into
> >> /usr/lib/cups/filter.
> >
> > No gstoraster. You aren't going anywhere. You will not be able to print.
> >
> > [...]
> >
> > "UnifiedLinuxDriver" indicates a package downloaded from
> >
> >  http://www.bchemnet.com/suldr/
> >
> > But there is no version 1.02 offered by this site, See here
> >
> >  http://www.bchemnet.com/suldr/suld.html
> >
> > Copying the PPD and filter is ok. But what file did you copy them from?
> > UnifiedLinuxDriver_1.02.tar.gz is not offered by the bchemnet.com site.
> >
> > Have you got that, too. The file you say you downloaded does not exist
> > at bchemnet.com as far as I can see.
> 
> 
> I downloaded - years ago, when I bought the printer - from:
> 
>  http://www.samsung.com

You were asked from where you got the package a couple of mails ago. I
should have insisted you answer rather than guessing from a file name.

Your best strategy is to download the latest package from Samsung
instead of using something ancient.

Alternatively, changing

 *cupsFilter:  "application/vnd.cups-postscript 0 rastertosamsungspl"

to

 *cupsFilter:  "application/vnd.cups-raster 0 rastertosamsungspl"

just might work.


> .  With those two files, the printer had always worked fine with Debian.  Now I
> installed Debian on a new machine, and the printer won't print.  Strange
> because the old machine, where the printer still does work, *also* has Debian
> Sid, the same operating system I have on my new Lenovo AMD A6 Desktop.
> 
> 
> >> > You have rastertosamsungspl as a filter. It needs to be given raster
> >> > data. It looks like it is being given PostScript - so the filter stops.
> >> >
> >> > Also provide the outputs of
> >> >
> >> >  cat /etc/cups/ppd/ppd_for_the printer | grep NickName
> >> 
> >> Here it is:
> >> 
> >> # cat Samsung_ML-191x_252x_Series.ppd | grep NickName
> >> *ShortNickName: "ML-191x 252x"
> >> *NickName:      "Samsung ML-191x 252x Series"
> >
> > Now - that looks ok
> >
> >> > and 
> >> >
> >> >  cat /etc/cups/ppd/ppd_for_the printer | grep cupsFilter
> >> >
> >> > You will probably have to be root to get these.
> >> 
> >> and:
> >> 
> >> # cat Samsung_ML-191x_252x_Series.ppd | grep cupsFilter
> >> *cupsFilter:  "application/vnd.cups-postscript 0 rastertosamsungspl"
> >> 
> >> What now?  Thanks...
> >
> > What now?
> >
> > Whatever package you are using is expecting rastertosamsungspl to process
> > PostScript. As its name implies, it will only process raster data. CUPS
> > will not like this line.
> >
> > Please post
> >
> >  cat Samsung_ML-191x_252x_Series.ppd | grep cupsFilter
> >
> > for the machine which prints for you. Check the PPD file name in
> > /etc/cups.ppd first.
> 
> 
> Here it is:
> 
> *cupsFilter:  "application/vnd.cups-postscript 0 rastertosamsungspl"
> 
> , but exactly the same output also comes from Lenovo machine, where the printer
> won't work...  So I think there must be some other different special reason
> because one is ok and the other is not although the system is the same on both.

I very much doubt the filtering on both machines is identical. The
error_log you posted for the non-working machine had

 D [07/Mar/2017:14:35:23 +0000] [Job 1] Started filter /usr/lib/cups/filter/pdftopdf (PID 4741)
 D [07/Mar/2017:14:35:23 +0000] [Job 1] Started filter /usr/lib/cups/filter/pdftops (PID 4742)
 D [07/Mar/2017:14:35:23 +0000] [Job 1] Started filter /usr/lib/cups/filter/rastertosamsungspl

PostScript is being produced. There is no pstoraster filter in unstable's
cups-filters package to give raster data to rastertosamsungspl.

Please run

 cupsfilter --list-filters -p /etc/cups/ppd/<ML-191x_ppd> -m printer/foo <input> -e > out.prn 2> log

on both machines. A PDF or a text file would do for <input>. Post the
two logs you get.

-- 
Brian.

[toc] | [prev] | [next] | [standalone]


#179424 — Re: `Filter failed' no print error message

FromRodolfo Medina <rodolfo.medina@gmail.com>
Date2017-03-27 08:50 +0200
SubjectRe: `Filter failed' no print error message
Message-ID<tpwDw-3Q9-27@gated-at.bofh.it>
In reply to#179413
Brian <ad44@cityscape.co.uk> writes:

>> > "UnifiedLinuxDriver" indicates a package downloaded from
>> >
>> >  http://www.bchemnet.com/suldr/
>> >
>> > But there is no version 1.02 offered by this site, See here
>> >
>> >  http://www.bchemnet.com/suldr/suld.html
>> >
>> > Copying the PPD and filter is ok. But what file did you copy them from?
>> > UnifiedLinuxDriver_1.02.tar.gz is not offered by the bchemnet.com site.
>> >
>> > Have you got that, too. The file you say you downloaded does not exist
>> > at bchemnet.com as far as I can see.
>> 
>> 
>> I downloaded - years ago, when I bought the printer - from:
>> 
>>  http://www.samsung.com
>
> You were asked from where you got the package a couple of mails ago. I
> should have insisted you answer rather than guessing from a file name.
>
> Your best strategy is to download the latest package from Samsung
> instead of using something ancient.

>From Samsung web site I don't find that package...


> Alternatively, changing
>
>  *cupsFilter:  "application/vnd.cups-postscript 0 rastertosamsungspl"
>
> to
>
>  *cupsFilter:  "application/vnd.cups-raster 0 rastertosamsungspl"
>
> just might work.

Unfortunately, it doesn't...


>> .  With those two files, the printer had always worked fine with Debian.
>> Now I installed Debian on a new machine, and the printer won't print.
>> Strange because the old machine, where the printer still does work, *also*
>> has Debian Sid, the same operating system I have on my new Lenovo AMD A6
>> Desktop.
>> 
>> 
>> > Whatever package you are using is expecting rastertosamsungspl to process
>> > PostScript. As its name implies, it will only process raster data. CUPS
>> > will not like this line.
>> >
>> > Please post
>> >
>> >  cat Samsung_ML-191x_252x_Series.ppd | grep cupsFilter
>> >
>> > for the machine which prints for you. Check the PPD file name in
>> > /etc/cups.ppd first.
>> 
>> 
>> Here it is:
>> 
>> *cupsFilter:  "application/vnd.cups-postscript 0 rastertosamsungspl"
>> 
>> , but exactly the same output also comes from Lenovo machine, where the
>> printer
>> won't work...  So I think there must be some other different special reason
>> because one is ok and the other is not although the system is the same on
>> both.
>
> I very much doubt the filtering on both machines is identical. The
> error_log you posted for the non-working machine had
>
>  D [07/Mar/2017:14:35:23 +0000] [Job 1] Started filter
> /usr/lib/cups/filter/pdftopdf (PID 4741)
>  D [07/Mar/2017:14:35:23 +0000] [Job 1] Started filter
> /usr/lib/cups/filter/pdftops (PID 4742)
>  D [07/Mar/2017:14:35:23 +0000] [Job 1] Started filter
> /usr/lib/cups/filter/rastertosamsungspl
>
> PostScript is being produced. There is no pstoraster filter in unstable's
> cups-filters package to give raster data to rastertosamsungspl.
>
> Please run
>
>  cupsfilter --list-filters -p /etc/cups/ppd/<ML-191x_ppd> -m printer/foo
> <input> -e > out.prn 2> log
>
> on both machines. A PDF or a text file would do for <input>. Post the
> two logs you get.

I suppose you mean something like:

 # cupsfilter --list-filters -p /etc/cups/ppd/Samsung_ML-191x_252x_Series.ppd -m printer/foo <input> -e > out.prn 2> log

, but what in place of `printer/foo' and <input>?

Thanks,

Rodolfo

[toc] | [prev] | [next] | [standalone]


#179432 — Re: `Filter failed' no print error message

FromBrian <ad44@cityscape.co.uk>
Date2017-03-27 13:10 +0200
SubjectRe: `Filter failed' no print error message
Message-ID<tpAH8-75T-13@gated-at.bofh.it>
In reply to#179424
On Mon 27 Mar 2017 at 07:42:35 +0100, Rodolfo Medina wrote:

> Brian <ad44@cityscape.co.uk> writes:
> >
> > Your best strategy is to download the latest package from Samsung
> > instead of using something ancient.
> 
> From Samsung web site I don't find that package...

I suppose this is the printer:

 http://www.samsung.com/uk/support/model/ML-1910/SEE

There is a "Downloads" section. Click "SEE MORE". You want to download
"Printing & Scan Driver ver V1.00.06, Linux".

> > I very much doubt the filtering on both machines is identical. The
> > error_log you posted for the non-working machine had
> >
> >  D [07/Mar/2017:14:35:23 +0000] [Job 1] Started filter
> > /usr/lib/cups/filter/pdftopdf (PID 4741)
> >  D [07/Mar/2017:14:35:23 +0000] [Job 1] Started filter
> > /usr/lib/cups/filter/pdftops (PID 4742)
> >  D [07/Mar/2017:14:35:23 +0000] [Job 1] Started filter
> > /usr/lib/cups/filter/rastertosamsungspl
> >
> > PostScript is being produced. There is no pstoraster filter in unstable's
> > cups-filters package to give raster data to rastertosamsungspl.
> >
> > Please run
> >
> >  cupsfilter --list-filters -p /etc/cups/ppd/<ML-191x_ppd> -m printer/foo <input> -e > out.prn 2> log
> >
> > on both machines. A PDF or a text file would do for <input>. Post the
> > two logs you get.
> 
> I suppose you mean something like:
> 
>  # cupsfilter --list-filters -p /etc/cups/ppd/Samsung_ML-191x_252x_Series.ppd -m printer/foo <input> -e > out.prn 2> log

That's fine, but do not use the --list-filters option. In other words:

cupsfilter -p /etc/cups/ppd/Samsung_ML-191x_252x_Series.ppd -m printer/foo /etc/nsswitch -e > out.prn 2> log

and post the logs.

> , but what in place of `printer/foo' and <input>?

printer/foo is ok. Use /etc/nsswitch for <input>.

-- 
Brian.

[toc] | [prev] | [next] | [standalone]


#179455 — Re: `Filter failed' no print error message

FromRodolfo Medina <rodolfo.medina@gmail.com>
Date2017-03-27 15:40 +0200
SubjectRe: `Filter failed' no print error message
Message-ID<tpD2i-kn-23@gated-at.bofh.it>
In reply to#179432
Brian <ad44@cityscape.co.uk> writes:

> I suppose this is the printer:
>
>  http://www.samsung.com/uk/support/model/ML-1910/SEE

Rather this:

 http://www.samsung.com/uk/support/model/ML-1915/SEE


> There is a "Downloads" section. Click "SEE MORE". You want to download
> "Printing & Scan Driver ver V1.00.06, Linux".

Thanks, I will.


>> > Please run
>> >
>> >  cupsfilter --list-filters -p /etc/cups/ppd/<ML-191x_ppd> -m printer/foo
>> > <input> -e > out.prn 2> log
>> >
>> > on both machines. A PDF or a text file would do for <input>. Post the
>> > two logs you get.
>> 
>> I suppose you mean something like:
>> 
>>  # cupsfilter --list-filters -p /etc/cups/ppd/Samsung_ML-191x_252x_Series.ppd -m printer/foo <input> -e > out.prn 2> log
>
> That's fine, but do not use the --list-filters option. In other words:
>
> cupsfilter -p /etc/cups/ppd/Samsung_ML-191x_252x_Series.ppd -m printer/foo
> /etc/nsswitch -e > out.prn 2> log
>
> and post the logs.
>
>> , but what in place of `printer/foo' and <input>?
>
> printer/foo is ok. Use /etc/nsswitch for <input>.

>From the non-working machine:

cupsfilter: File "/usr/lib/cups/filter/rastertosamsungspl" permissions OK (040755/uid=0/gid=0).
cupsfilter: Unable to determine MIME type of "/etc/nsswitch".


, and from the working:

cupsfilter: File "/usr/lib/cups/filter/rastertosamsungspl" permissions OK (040755/uid=0/gid=0).
cupsfilter: File "/usr/lib/cups/filter/commandtops" permissions OK (040755/uid=0/gid=0).
cupsfilter: Unable to determine MIME type of "/etc/nsswitch".


Thanks,

Rodolfo

[toc] | [prev] | [next] | [standalone]


#179465 — Re: `Filter failed' no print error message

FromBrian <ad44@cityscape.co.uk>
Date2017-03-27 16:40 +0200
SubjectRe: `Filter failed' no print error message
Message-ID<tpDYm-XG-25@gated-at.bofh.it>
In reply to#179455
On Mon 27 Mar 2017 at 14:29:31 +0100, Rodolfo Medina wrote:

> Brian <ad44@cityscape.co.uk> writes:
> 
> > I suppose this is the printer:
> >
> >  http://www.samsung.com/uk/support/model/ML-1910/SEE
> 
> Rather this:
> 
>  http://www.samsung.com/uk/support/model/ML-1915/SEE

It doesn't matter. You'll gat the same uld file for both.

> > There is a "Downloads" section. Click "SEE MORE". You want to download
> > "Printing & Scan Driver ver V1.00.06, Linux".
> 
> Thanks, I will.
> 
> 
> >> > Please run
> >> >
> >> >  cupsfilter --list-filters -p /etc/cups/ppd/<ML-191x_ppd> -m printer/foo
> >> > <input> -e > out.prn 2> log
> >> >
> >> > on both machines. A PDF or a text file would do for <input>. Post the
> >> > two logs you get.
> >> 
> >> I suppose you mean something like:
> >> 
> >>  # cupsfilter --list-filters -p /etc/cups/ppd/Samsung_ML-191x_252x_Series.ppd -m printer/foo <input> -e > out.prn 2> log
> >
> > That's fine, but do not use the --list-filters option. In other words:
> >
> > cupsfilter -p /etc/cups/ppd/Samsung_ML-191x_252x_Series.ppd -m printer/foo
> > /etc/nsswitch -e > out.prn 2> log
> >
> > and post the logs.
> >
> >> , but what in place of `printer/foo' and <input>?
> >
> > printer/foo is ok. Use /etc/nsswitch for <input>.
> 
> >From the non-working machine:
> 
> cupsfilter: File "/usr/lib/cups/filter/rastertosamsungspl" permissions OK (040755/uid=0/gid=0).
> cupsfilter: Unable to determine MIME type of "/etc/nsswitch".
> 
> 
> , and from the working:
> 
> cupsfilter: File "/usr/lib/cups/filter/rastertosamsungspl" permissions OK (040755/uid=0/gid=0).
> cupsfilter: File "/usr/lib/cups/filter/commandtops" permissions OK (040755/uid=0/gid=0).
> cupsfilter: Unable to determine MIME type of "/etc/nsswitch".

You were particlarly asked not to use the --list-filters switch. Please
would you repeat the command

 cupsfilter -p /etc/cups/ppd/Samsung_ML-191x_252x_Series.ppd -m printer/foo /etc/nsswitch -e > out.prn 2> log

and post again.

-- 
Brian.

[toc] | [prev] | [next] | [standalone]


#179469 — Re: `Filter failed' no print error message

FromRodolfo Medina <rodolfo.medina@gmail.com>
Date2017-03-27 17:10 +0200
SubjectRe: `Filter failed' no print error message
Message-ID<tpErp-1wA-45@gated-at.bofh.it>
In reply to#179465
Brian <ad44@cityscape.co.uk> writes:

> On Mon 27 Mar 2017 at 14:29:31 +0100, Rodolfo Medina wrote:
>
>> Brian <ad44@cityscape.co.uk> writes:
>> 
>> > I suppose this is the printer:
>> >
>> >  http://www.samsung.com/uk/support/model/ML-1910/SEE
>> 
>> Rather this:
>> 
>>  http://www.samsung.com/uk/support/model/ML-1915/SEE
>
> It doesn't matter. You'll gat the same uld file for both.
>
>> > There is a "Downloads" section. Click "SEE MORE". You want to download
>> > "Printing & Scan Driver ver V1.00.06, Linux".
>> 
>> Thanks, I will.
>> 
>> 
>> >> > Please run
>> >> >
>> >> >  cupsfilter --list-filters -p /etc/cups/ppd/<ML-191x_ppd> -m printer/foo
>> >> > <input> -e > out.prn 2> log
>> >> >
>> >> > on both machines. A PDF or a text file would do for <input>. Post the
>> >> > two logs you get.
>> >> 
>> >> I suppose you mean something like:
>> >> 
>> >>  # cupsfilter --list-filters -p
>> >> /etc/cups/ppd/Samsung_ML-191x_252x_Series.ppd -m printer/foo <input> -e >
>> >> out.prn 2> log
>> >
>> > That's fine, but do not use the --list-filters option. In other words:
>> >
>> > cupsfilter -p /etc/cups/ppd/Samsung_ML-191x_252x_Series.ppd -m printer/foo
>> > /etc/nsswitch -e > out.prn 2> log
>> >
>> > and post the logs.
>> >
>> >> , but what in place of `printer/foo' and <input>?
>> >
>> > printer/foo is ok. Use /etc/nsswitch for <input>.
>> 
>> >From the non-working machine:
>> 
>> cupsfilter: File "/usr/lib/cups/filter/rastertosamsungspl" permissions OK
>> (040755/uid=0/gid=0).
>> cupsfilter: Unable to determine MIME type of "/etc/nsswitch".
>> 
>> 
>> , and from the working:
>> 
>> cupsfilter: File "/usr/lib/cups/filter/rastertosamsungspl" permissions OK
>> (040755/uid=0/gid=0).
>> cupsfilter: File "/usr/lib/cups/filter/commandtops" permissions OK
>> (040755/uid=0/gid=0).
>> cupsfilter: Unable to determine MIME type of "/etc/nsswitch".
>
> You were particlarly asked not to use the --list-filters switch.

In fact I didn't use it at all.


> Please would you repeat the command
>
>  cupsfilter -p /etc/cups/ppd/Samsung_ML-191x_252x_Series.ppd -m printer/foo
> /etc/nsswitch -e > out.prn 2> log
>
> and post again.


Now they are both:

cupsfilter: File "/usr/lib/cups/filter/rastertosamsungspl" permissions OK
(040755/uid=0/gid=0).
cupsfilter: File "/usr/lib/cups/filter/commandtops" permissions OK
(040755/uid=0/gid=0).
cupsfilter: Unable to determine MIME type of "/etc/nsswitch".

Thanks,

Rodolfo

[toc] | [prev] | [next] | [standalone]


#179478 — Re: `Filter failed' no print error message

FromBrian <ad44@cityscape.co.uk>
Date2017-03-27 18:20 +0200
SubjectRe: `Filter failed' no print error message
Message-ID<tpFx8-2mb-29@gated-at.bofh.it>
In reply to#179469
On Mon 27 Mar 2017 at 16:04:31 +0100, Rodolfo Medina wrote:

> Brian <ad44@cityscape.co.uk> writes:
> 
> > Please would you repeat the command
> >
> >  cupsfilter -p /etc/cups/ppd/Samsung_ML-191x_252x_Series.ppd -m printer/foo
> > /etc/nsswitch -e > out.prn 2> log
> >
> > and post again.
> 
> Now they are both:
> 
> cupsfilter: File "/usr/lib/cups/filter/rastertosamsungspl" permissions OK
> (040755/uid=0/gid=0).
> cupsfilter: File "/usr/lib/cups/filter/commandtops" permissions OK
> (040755/uid=0/gid=0).
> cupsfilter: Unable to determine MIME type of "/etc/nsswitch".

The output should be at least a screenful of text. Do you still get your
previous output with

 cupsfilter -p /etc/cups/ppd/Samsung_ML-191x_252x_Series.ppd -m printer/foo /etc/nsswitch -e > out.prn ?

That is, don't direct the error output to a file but to the screen.

How about

 cupsfilter /etc/nsswitch > out.prn ?

That should give more than one line of output.

(Unable to determine MIME type of "/etc/nsswitch" is perturbing).

-- 
Brian.

[toc] | [prev] | [next] | [standalone]


#179480 — Re: `Filter failed' no print error message

FromRodolfo Medina <rodolfo.medina@gmail.com>
Date2017-03-27 19:30 +0200
SubjectRe: `Filter failed' no print error message
Message-ID<tpGCR-37r-15@gated-at.bofh.it>
In reply to#179478
Brian <ad44@cityscape.co.uk> writes:

> On Mon 27 Mar 2017 at 16:04:31 +0100, Rodolfo Medina wrote:
>
>> Brian <ad44@cityscape.co.uk> writes:
>> 
>> > Please would you repeat the command
>> >
>> >  cupsfilter -p /etc/cups/ppd/Samsung_ML-191x_252x_Series.ppd -m printer/foo
>> > /etc/nsswitch -e > out.prn 2> log
>> >
>> > and post again.
>> 
>> Now they are both:
>> 
>> cupsfilter: File "/usr/lib/cups/filter/rastertosamsungspl" permissions OK
>> (040755/uid=0/gid=0).
>> cupsfilter: File "/usr/lib/cups/filter/commandtops" permissions OK
>> (040755/uid=0/gid=0).
>> cupsfilter: Unable to determine MIME type of "/etc/nsswitch".
>
> The output should be at least a screenful of text. Do you still get your
> previous output with
>
>  cupsfilter -p /etc/cups/ppd/Samsung_ML-191x_252x_Series.ppd -m printer/foo
> /etc/nsswitch -e > out.prn ?
>
> That is, don't direct the error output to a file but to the screen.

Yes, same as previous...


> How about
>
>  cupsfilter /etc/nsswitch > out.prn ?
>
> That should give more than one line of output.
>
> (Unable to determine MIME type of "/etc/nsswitch" is perturbing).

In this case, the output is:

 cupsfilter: Unable to determine MIME type of "/etc/nsswitch".

on both machines...

Thanks,

Rodolfo

[toc] | [prev] | [next] | [standalone]


Page 2 of 3 — ← Prev page 1 [2] 3  Next page →

Back to top | Article view | linux.debian.user


csiph-web